==> randovania-2.5.0.tar.gz: randovania-2.5.0/PRIVACY_POLICY.md <==
# Randovania Privacy Policy

This privacy policy will explain how Randovania uses the personal data we collect from you when you use our application.


## What data do we collect?

Randovania collects the following data:
* Personal identification information (Discord id and username)

## How do we collect your data?

You directly provide Randovania with the data we collect. We collect data and process data when you:
* Login via a Discord account.
* Join an online game session.

## How will we use your data?

Randovania collects your data so that we can:
* Consistently identify you across multiple sessions
* Associate you with a game session, along with a name.

Randovania will not share your data with any third-parties.

## How do we store your data?

Randovania stores your data at our server hosted by [DigitalOcean](https://www.digitalocean.com/) in their Frankfurt datacenter. Only trusted developers have access to this server.

Randovania will currently keep your data for an indefinite length of time.

## What are your data protection rights?

Randovania would like to make sure you are fully aware of all of your data protection rights. Every user is entitled to the following:

**The right to access** - You have the right to request Randovana for copies of your personal data.

**The right to rectification** - You have the right to request that Randovania correct any information you believe is inaccurate. You also have the right to request Randovania to complete information you believe is incomplete.

**The right to erasure** - You have the right to request that Randovania erase your personal data, under certain conditions.

If you make a request, we have one month to respond to you. If you would like to exercise any of these rights, please contact us.
 
## Changes to our privacy policy

Randovania keeps its privacy policy under regular review and places any updates on address. This privacy policy was last updated on 21 October 2020.

## How to contact us

If you have any questions about Randovania's privacy policy, the data we hold on you, or you would like to exercise one of your data protection rights, please do not hesitate to contact us.

* [Create an issue](https://github.com/randovania/randovania/issues/new) in Randovania's repository.
* Contact an Admin in the [Metroid Prime Randomizer Discord](https://discordapp.com/invite/gymstUz).

==> randovania-10.3.0.tar.gz: randovania-10.3.0/PRIVACY_POLICY.md <==
# Randovania Privacy Policy

This privacy policy will explain how Randovania uses the personal data we collect from you when you use our application.


## What data do we collect?

Randovania collects the following data:
* Personal identification information (Discord id and username)

## How do we collect your data?

You directly provide Randovania with the data we collect. We collect data and process data when you:
* Login via a Discord account.
* Join an online game session.

## How will we use your data?

Randovania collects your data so that we can:
* Consistently identify you across multiple sessions
* Associate you with a game session, along with a name.

Randovania will attach your Discord id and username to any reports sent to [Sentry](https://sentry.io/), but you can opt out of this behavior. 

Randovania will not share your data with any other third-parties.

## How do we store your data?

Randovania stores your data at our server hosted by [DigitalOcean](https://www.digitalocean.com/) in their Frankfurt datacenter. Only trusted developers have access to this server.

Randovania will currently keep your data for an indefinite length of time.

The data stored by Sentry can only be accessed by trusted developers and is deleted after 90 days.

## What are your data protection rights?

Randovania would like to make sure you are fully aware of all of your data protection rights. Every user is entitled to the following:

**The right to access** - You have the right to request Randovania for copies of your personal data.

**The right to rectification** - You have the right to request that Randovania correct any information you believe is inaccurate. You also have the right to request Randovania to complete information you believe is incomplete.

**The right to erasure** - You have the right to request that Randovania erase your personal data, under certain conditions.

If you make a request, we have one month to respond to you. If you would like to exercise any of these rights, please contact us.
 
## Changes to our privacy policy

Randovania keeps its privacy policy under regular review and places any updates on address. This privacy policy was last updated on 4 July 2023.

## How to contact us

If you have any questions about Randovania's privacy policy, the data we hold on you, or you would like to exercise one of your data protection rights, please do not hesitate to contact us.

* [Create an issue](https://github.com/randovania/randovania/issues/new) in Randovania's repository.
* Contact an Admin, Moderator or Core Dev in the [Randovania Discord](https://discord.gg/M23gCxj6fw).
